From: Josh Poimboeuf <jpoimboe@redhat.com>
To: Zhou Chengming <zhouchengming1@huawei.com>
Cc: live-patching@vger.kernel.org, linux-kernel@vger.kernel.org,
jeyu@redhat.com, jikos@kernel.org, mbenes@suse.cz,
pmladek@suse.com, huawei.libin@huawei.com
Subject: Re: [PATCH v2] livepatch: Reduce the time of finding module symbols
Date: Wed, 29 Mar 2017 09:59:07 -0500 [thread overview]
Message-ID: <20170329145907.a2y7uvysxj52jix2@treble> (raw)
In-Reply-To: <1490706635-45752-1-git-send-email-zhouchengming1@huawei.com>
On Tue, Mar 28, 2017 at 09:10:35PM +0800, Zhou Chengming wrote:
> It's reported that the time of insmoding a klp.ko for one of our
> out-tree modules is too long.
>
> ~ time sudo insmod klp.ko
> real 0m23.799s
> user 0m0.036s
> sys 0m21.256s
>
> Then we found the reason: our out-tree module used a lot of static local
> variables, so klp.ko has a lot of relocation records which reference the
> module. Then for each such entry klp_find_object_symbol() is called to
> resolve it, but this function uses the interface kallsyms_on_each_symbol()
> even for finding module symbols, so will waste a lot of time on walking
> through vmlinux kallsyms table many times.
>
> This patch changes it to use module_kallsyms_on_each_symbol() for modules
> symbols. After we apply this patch, the sys time reduced dramatically.
>
> ~ time sudo insmod klp.ko
> real 0m1.007s
> user 0m0.032s
> sys 0m0.924s
>
> Signed-off-by: Zhou Chengming <zhouchengming1@huawei.com>
It would be good to make kallsyms faster, but either way this still a
performance improvement for patching modules.
Acked-by: Josh Poimboeuf <jpoimboe@redhat.com>
--
Josh
next prev parent reply other threads:[~2017-03-29 14:59 UTC|newest]
Thread overview: 5+ messages / expand[flat|nested] mbox.gz Atom feed top
2017-03-28 13:10 Zhou Chengming
2017-03-29 14:59 ` Josh Poimboeuf [this message]
2017-03-29 19:40 ` Jessica Yu
2017-03-30 8:01 ` Miroslav Benes
2017-03-30 8:42 ` Jiri Kosina
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20170329145907.a2y7uvysxj52jix2@treble \
--to=jpoimboe@redhat.com \
--cc=huawei.libin@huawei.com \
--cc=jeyu@redhat.com \
--cc=jikos@kernel.org \
--cc=linux-kernel@vger.kernel.org \
--cc=live-patching@vger.kernel.org \
--cc=mbenes@suse.cz \
--cc=pmladek@suse.com \
--cc=zhouchengming1@huawei.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®